==> gc_board_0.09.00.tar.gz: gc_board_0.09.00/admin/uninstall.php <==
<?php
///////////////////////////////////////////////////////////////////////////
// uninstall.php
// gc_board   ù ° 
// 2005. 7. 19.
///////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////
// ⺻ ʿ  
///////////////////////////////////////////////////////////////////////////
require "../include/gc_manage_lib.php";

///////////////////////////////////////////////////////////////////////////
//  Ȯ (root α ¿ )
///////////////////////////////////////////////////////////////////////////
chk_admin();

///////////////////////////////////////////////////////////////////////////
// Խ 
///////////////////////////////////////////////////////////////////////////
$board_sel_query = "select tblname from gc_board_info";
$board_sel_row = gc_query($board_sel_query);
if ($board_sel_row != 0)
{
	for ($i=0; $i<sizeof($board_sel_row); $i++)
	{
		$now_tblname = $board_sel_row[$i]["tblname"];

		$main_del_query = "drop table gc_board_main_".$now_tblname;
		gc_query($main_del_query);

		$comment_del_query = "drop table gc_board_comment_".$now_tblname;
		gc_query($comment_del_query);
		
		del_dir("../board/files/".$now_tblname);
	}
}

$board_del_query = "drop table gc_board_info";
gc_query($board_del_query);

$masters_del_query = "drop table gc_board_masters";
gc_query($masters_del_query);

///////////////////////////////////////////////////////////////////////////
// ȸ 
///////////////////////////////////////////////////////////////////////////
$member_del_query = "drop table gc_member";
gc_query($member_del_query);

$entrance_del_query = "drop table gc_member_entrance";
gc_query($entrance_del_query);

$memo_del_query = "drop table gc_memo";
gc_query($memo_del_query);

$zipcode_del_query = "drop table zipcode";
gc_query($zipcode_del_query);

$level_del_query = "drop table gc_level";
gc_query($level_del_query);

///////////////////////////////////////////////////////////////////////////
// ⺻  
///////////////////////////////////////////////////////////////////////////
$menu_del_query = "drop table gc_admin_menu";
gc_query($menu_del_query);

$config_del_query = "drop table gc_basic_config";
gc_query($config_del_query);

@unlink("../config/db_info.php");

///////////////////////////////////////////////////////////////////////////
// Ϸ   ̵
///////////////////////////////////////////////////////////////////////////
?>
<script language="javascript">
	alert('gc_board Ǿϴ.');
	parent.document.location.href='../index.php';
</script>

==> gc_board_0.09.01.tar.gz: gc_board_0.09.01/admin/uninstall.php <==
<?php
///////////////////////////////////////////////////////////////////////////
// uninstall.php
// gc_board   ù ° 
// 2005. 8. 24.
///////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////
// ⺻ ʿ  
///////////////////////////////////////////////////////////////////////////
require "../include/gc_manage_lib.php";

///////////////////////////////////////////////////////////////////////////
//  Ȯ (root α ¿ )
///////////////////////////////////////////////////////////////////////////
chk_admin();

///////////////////////////////////////////////////////////////////////////
// Խ 
///////////////////////////////////////////////////////////////////////////
$board_sel_query = "select tblname from gc_board_info";
$board_sel_row = gc_query($board_sel_query);
if ($board_sel_row != 0)
{
	for ($i=0; $i<sizeof($board_sel_row); $i++)
	{
		$now_tblname = $board_sel_row[$i]["tblname"];

		$main_del_query = "drop table gc_board_main_".$now_tblname;
		gc_query($main_del_query);

		$comment_del_query = "drop table gc_board_comment_".$now_tblname;
		gc_query($comment_del_query);
		
		del_dir("../board/files/".$now_tblname);
	}
}

$board_del_query = "drop table gc_board_info";
gc_query($board_del_query);

$masters_del_query = "drop table gc_board_masters";
gc_query($masters_del_query);

///////////////////////////////////////////////////////////////////////////
// ȸ 
///////////////////////////////////////////////////////////////////////////
$member_del_query = "drop table gc_member";
gc_query($member_del_query);

$entrance_del_query = "drop table gc_member_entrance";
gc_query($entrance_del_query);

$memo_del_query = "drop table gc_memo";
gc_query($memo_del_query);

$zipcode_del_query = "drop table gc_zipcode";
gc_query($zipcode_del_query);

$level_del_query = "drop table gc_level";
gc_query($level_del_query);

///////////////////////////////////////////////////////////////////////////
// ⺻  
///////////////////////////////////////////////////////////////////////////
$menu_del_query = "drop table gc_admin_menu";
gc_query($menu_del_query);

$config_del_query = "drop table gc_basic_config";
gc_query($config_del_query);

@unlink("../config/db_info.php");

///////////////////////////////////////////////////////////////////////////
// Ϸ   ̵
///////////////////////////////////////////////////////////////////////////
?>
<script language="javascript">
	alert('gc_board Ǿϴ.');
	parent.document.location.href='../index.php';
</script>
